<?php
/*
Plugin Name:  FireCask's Twitter Follow Button
Plugin URI:   https://firecask.com/services/development/wordpress/
Description:  Quickly adds the Twitter follow button. Can be easily implemented into your page, post or theme template
Version:      0.3
Author:       Alex Moss
Author URI:   https://alex-moss.co.uk/
Contributors: alexmoss, pleer

Copyright (C) 2010-2024, Alex Moss
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
Neither the name of Alex Moss or pleer nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/

function twitterfollowbutton($atts) {
    $atts = shortcode_atts(array(
        'username' => 'alexmoss',
        'scheme'   => 'light',
        'count'    => 'yes',
        'lang'     => 'en',
    ), $atts, 'twitter-follow');

    // Handle invalid username
    if ( ! preg_match( '/^[A-Za-z0-9_]{1,15}$/', $username ) ) {
        return 'Invalid Twitter username.';
    }

    // Sanitize and validate the attributes
    $username = sanitize_text_field($atts['username']);
    $scheme   = ($atts['scheme'] === 'dark') ? 'dark' : 'light';
    $count    = ($atts['count'] === 'no') ? 'no' : 'yes';
    $lang     = sanitize_text_field($atts['lang']);

    $tfscheme = '';
    $tfcount  = '';
    $tflang   = '';

	if ($scheme === 'dark') {
        $tfscheme = ' data-button="grey" data-text-color="#FFFFFF" data-link-color="#00AEFF"';
    }

    if ($count === 'no') {
        $tfcount = ' data-show-count="false"';
    }

    if ($lang !== 'en') {
        $tflang = ' data-lang="' . esc_attr($lang) . '"';
    }

    // Build the follow button HTML with proper escaping
    $followbutton  = "<!-- WordPress Follow Button Shortcode for WordPress: https://firecask.com/services/development/wordpress/ -->\n";
    $followbutton .= '<a href="https://twitter.com/' . esc_attr($username) . '" class="twitter-follow-button" rel="external nofollow"' . $tfscheme . $tfcount . $tflang . '>Follow @' . esc_html($username) . '</a>' . "\n";
    $followbutton .= '<script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>';

    return $followbutton;
}
add_filter('widget_text', 'do_shortcode');
add_shortcode('twitter-follow', 'twitterfollowbutton');
?>